; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule cpu-data-missing
  "Check that cpu data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? cpu $?) (clck-mode ?mode))
  (object (is-a NODE) (node_id ?node) (role $?node-role))
  (not (object (is-a CPU) (node_id ?node)))
  (test (or (and (eq ?mode health)
                 (or (member$ compute ?node-role) (member$ enhanced ?node-role)))
            (or  (eq ?mode compliance) (eq ?mode certification))))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "cpu-data-missing")
                 (remedy "cpu-data-missing-remedy")))

(defrule cpu-not-intel64
  "Check that the cpu is a 64 bit Intel(R) processor."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? cpu $?))
  ?obj <- (object (is-a CPU) (node_id ?node) (flags $?flags)
                  (vendor-id ?vendor))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (test (or (!= (str-compare ?vendor "GenuineIntel") 0)
            (not (member$ lm ?flags))))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 80)
                 (state observed) (source ?obj) (value TRUE)
                 (id "cpu-not-intel64")))

(defrule cpu-model-name-not-uniform
  "Check that the cpu model-name is uniform."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? cpu $?))
  ?obj <- (object (is-a CPU) (node_id ?node) (model-name ?m))
  (object (is-a NODE) (node_id ?node))
  (test (< (send ?obj fraction (send ?obj uniformity-key model-name) ?m) 0.9))
  =>
  (bind ?percent (* 100 (send ?obj fraction
                              (send ?obj uniformity-key model-name) ?m)))
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence (- 100 ?percent)) (severity 60)
                 (state observed) (source ?obj) (value TRUE)
                 (id "cpu-model-name-not-uniform")
                 (args (create$ ?m ?percent))))

(defrule cpu-data-is-too-old
  "Identify nodes where the most recent CPU data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a CPU specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config])
          (clck-mode certification | compliance | health)
          (clck-checks $? cpu $?) (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node))
  ?obj <- (object (is-a CPU) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "cpu-data-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "cpu-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))
