; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule hpl-data-missing
  "Check that hpl data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? hpl $?))
  (object (is-a NODE) (node_id ?node) (architecture x86_64)
          (role $?role&:(member$ compute ?role)|:(member$ enhanced ?role)))
  (not (object (is-a HPL) (node_id $?nodes&:(member$ ?node ?nodes))))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "hpl-data-missing")
                 (remedy "hpl-data-missing-remedy")))

(defrule hpl-cluster-failed
  "Look for cases where HPL cluster ran but there was no 'success' in
   the output."
  (object (is-a CONFIG) (name [config]) (clck-mode health | certification)
          (clck-checks $? hpl $?))
  ?obj <- (object (is-a HPL) (provider CLUSTER) (residual ~PASSED))
  =>
  (make-instance of BOOLEAN_SIGN (node_id (send ?obj get-node_id))
                 (confidence 90) (severity 90)
                 (state observed) (source ?obj) (value TRUE)
                 (id "hpl-cluster-failed")))

(defrule hpl-pairwise-failed
  "Look for cases where HPL pairwise ran but there was no 'success' in
   the output."
  (object (is-a CONFIG) (name [config]) (clck-mode health | certification)
          (clck-checks $? hpl $?))
  ?obj <- (object (is-a HPL) (provider PAIRWISE) (residual ~PASSED))
  =>
  (make-instance of BOOLEAN_SIGN (node_id (send ?obj get-node_id))
                 (confidence 90) (severity 90)
                 (state observed) (source ?obj) (value TRUE)
                 (id "hpl-pairwise-failed")))

(defrule hpl-pairwise-outlier
  "Locate values that are outliers.  An outlier is a value that is
   outside the range defined by the median +/- 6 * median absolute
   deviations.  The statistics are computed using all samples on nodes
   in the same grouping (i.e., have the same HPL statistics key).

   Note: the statistics_control condition is required to ensure that
   all samples are included when computing the statistics."
  (object (is-a CONFIG) (name [config]) (clck-mode health | certification)
          (clck-checks $? hpl $?) (hpl-number-of-mad ?num-mad)
          (outlier-max-median-mad-dist ?med-mad-dist)
          (outlier-median-pct ?median-pct))

  ?obj <- (object (is-a HPL) (provider PAIRWISE) (residual PASSED)
                (gflops ?GFLOPS) (statistics_control TRUE))

  (test (send ?obj outlier (send ?obj statistics-key) ?GFLOPS ?num-mad
              ?med-mad-dist ?median-pct))

  =>

  (bind ?key (send ?obj statistics-key))
  (bind ?stat-instance (send ?obj _find_pair ?key))

  (bind ?median (send ?stat-instance median))
  (bind ?margin (send ?stat-instance get-outlier-margin))

  (bind ?severity (send ?obj outlier-severity ?key ?GFLOPS 20 60))

  (make-instance of BOOLEAN_SIGN (node_id (send ?obj get-node_id))
                 (confidence 75) (severity ?severity)
                 (state observed) (source ?obj)
                 (id "hpl-pairwise-outlier")
                 (args (create$ ?GFLOPS ?median ?margin
                                (send ?obj get-impi-setting-string)))))

(defrule hpl-data-is-too-old
  "Identify nodes where the most recent HPL data should be considered too old.
   Will still fire when there is not a recent heartbeat, because even though
   this might not be a HPL specific issue, matching an HPL instance's arbitrary
   number of nodes is non-obvious.  Too old is defined to mean no data from
   the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config]) (clck-mode health | certification)
          (clck-checks $? hpl $?) (data-age-threshold ?age-threshold))
  ?obj <- (object (is-a HPL) (provider PAIRWISE | CLUSTER) (timestamp ?t))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id (send ?obj get-node_id)) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "hpl-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))
