; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule libraries-data-missing
  "Check that libraries data is available."
  (declare (salience ?*high-salience*))
  (object (is-a CONFIG) (name [config]) (clck-checks $? libraries $?))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a LIBRARIES) (node_id ?node)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "libraries-data-missing")
                 (remedy "libraries-data-missing-remedy")))

(defrule missing-libacl-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libacl.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libacl.so.1" "ILP32" "1.3.1"))))

(defrule missing-libattr-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libattr.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libattr.so.1" "ILP32" "1.3.1"))))

(defrule missing-libbz2-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libbz2.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libbz2.so.1" "ILP32" "1.3.1"))))

(defrule missing-libcap-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcap.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcap.so.2" "ILP32" "1.3.1"))))

(defrule missing-libncurses-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libncurses.so.5)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libncurses.so.5" "ILP32" "1.3.1"))))

(defrule missing-libncursesw-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libncursesw.so.5)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libncursesw.so.5" "ILP32" "1.3.1"))))

(defrule missing-libpam-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpam.so.0)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpam.so.0" "ILP32" "1.3.1"))))

(defrule missing-libz-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libz.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libz.so.1" "ILP32" "1.3.1"))))

(defrule missing-libacl-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libacl.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libacl.so.1" "LP64" ?iv))))

(defrule missing-libattr-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libattr.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libattr.so.1" "LP64" ?iv))))

(defrule missing-libbz2-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libbz2.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libbz2.so.1" "LP64" ?iv))))

(defrule missing-libcap-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcap.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcap.so.2" "LP64" ?iv))))

(defrule missing-libncurses-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libncurses.so.5)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libncurses.so.5" "LP64" ?iv))))

(defrule missing-libncursesw-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libncursesw.so.5)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libncursesw.so.5" "LP64" ?iv))))

(defrule missing-libpam-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpam.so.0)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpam.so.0" "LP64" ?iv))))

(defrule missing-libz-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libz.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libz.so.1" "LP64" ?iv))))

(defrule missing-libdrm-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libdrm.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libdrm.so.2" "LP64" "1.3.1"))))

(defrule missing-libfontconfig-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libfontconfig.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libfontconfig.so.1" "LP64" ?iv))))

(defrule missing-libfreetype-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libfreetype.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libfreetype.so.6" "LP64" ?iv))))

(defrule missing-libGL-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libGL.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libGL.so.1" "LP64" ?iv))))

(defrule missing-libGLU-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libGLU.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libGLU.so.1" "LP64" ?iv))))

(defrule missing-libICE-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libICE.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libICE.so.6" "LP64" ?iv))))

(defrule missing-libSM-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libSM.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libSM.so.6" "LP64" ?iv))))

(defrule missing-libX11-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libX11.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libX11.so.6" "LP64" ?iv))))

(defrule missing-libXRes-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXRes.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXRes.so.1" "LP64" "1.3.1"))))

(defrule missing-libXau-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXau.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXau.so.6" "LP64" ?iv))))

(defrule missing-libXcomposite-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXcomposite.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXcomposite.so.1" "LP64" "1.3.1"))))

(defrule missing-libXcursor-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXcursor.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXcursor.so.1" "LP64" ?iv))))


(defrule missing-libXdamage-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXdamage.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXdamage.so.1" "LP64" "1.3.1"))))

(defrule missing-libXdmcp-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXdmcp.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXdmcp.so.6" "LP64" "1.3.1"))))

(defrule missing-libXext-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version  ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXext.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXext.so.6" "LP64" ?iv))))

(defrule missing-libXfixes-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXfixes.so.3)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXfixes.so.3" "LP64" ?iv))))

(defrule missing-libXfont-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXfont.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXfont.so.1" "LP64" "1.3.1"))))

(defrule missing-libXft-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXft.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXft.so.2" "LP64" ?iv))))

(defrule missing-libXi-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXi.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXi.so.6" "LP64" ?iv))))

(defrule missing-libXinerama-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXinerama.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXinerama.so.1" "LP64" ?iv))))

(defrule missing-libXmu-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXmu.so.6)
               (libarch x86-64)))
 =>
 (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                (severity 80) (state observed) (source ?obj) (value TRUE)
                (id "missing-icr-library")
                (args (create$ "libXmu.so.6" "LP64" ?iv))))

(defrule missing-libXmuu-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXmuu.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXmuu.so.1" "LP64" "1.3.1"))))

(defrule missing-libXp-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXp.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXp.so.6" "LP64" ?iv))))

(defrule missing-libXrandr-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXrandr.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXrandr.so.2" "LP64" ?iv))))

(defrule missing-libXrender-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXrender.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXrender.so.1" "LP64" ?iv))))

(defrule missing-libXss-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXss.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXss.so.1" "LP64" "1.3.1"))))

(defrule missing-libXt-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXt.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXt.so.6" "LP64" ?iv))))

(defrule missing-libXtst-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXtst.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXtst.so.6" "LP64" ?iv))))

(defrule missing-libXv-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXv.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXv.so.1" "LP64" "1.3.1"))))

(defrule missing-libXvMC-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXvMC.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXvMC.so.1" "LP64" "1.3.1"))))

(defrule missing-libXxf86dga-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXxf86dga.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXxf86dga.so.1" "LP64" "1.3.1"))))

(defrule missing-libXxf86misc-x86-64
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXxf86misc.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXxf86misc.so.1" "LP64" "1.3.1"))))

(defrule missing-libXxf86vm-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libXxf86vm.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libXxf86vm.so.1" "LP64" ?iv))))

(defrule missing-ld-linux-x86
"Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname ld-linux.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "ld-linux.so.2" "ILP32" "1.3.1"))))

(defrule missing-ld-linux-x86-64-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname ld-linux-x86-64.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "ld-linux-x86-64.so.2" "LP64" ?iv))))

(defrule missing-libnuma-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnuma.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnuma.so.1" "LP64" ?iv))))

(defrule missing-libBrokenLocale-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libBrokenLocale.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libBrokenLocale.so.1" "ILP32" "1.3.1"))))

(defrule missing-libSegFault-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libSegFault.so)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libSegFault.so" "ILP32" "1.3.1"))))

(defrule missing-libanl-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libanl.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libanl.so.1" "ILP32" "1.3.1"))))

(defrule missing-libc-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libc.so.6)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libc.so.6" "ILP32" "1.3.1"))))

(defrule missing-libcidn-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcidn.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcidn.so.1" "ILP32" "1.3.1"))))

(defrule missing-libcrypt-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcrypt.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcrypt.so.1" "ILP32" "1.3.1"))))

(defrule missing-libcrypto-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcrypto.so.6)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcrypto.so.6" "ILP32" "1.3.1"))))

(defrule missing-libdl-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libdl.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libdl.so.2" "ILP32" "1.3.1"))))

(defrule missing-libgcc_s-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libgcc_s.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libgcc_s.so.1" "ILP32" "1.3.1"))))

(defrule missing-libm-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libm.so.6)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libm.so.6" "ILP32" "1.3.1"))))

(defrule missing-libnsl-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnsl.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnsl.so.1" "ILP32" "1.3.1"))))

(defrule missing-libnss_compat-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_compat.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_compat.so.2" "ILP32" "1.3.1"))))

(defrule missing-libnss_dns-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_dns.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_dns.so.2" "ILP32" "1.3.1"))))

(defrule missing-libnss_files-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_files.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_files.so.2" "ILP32" "1.3.1"))))

(defrule missing-libnss_hesiod-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_hesiod.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_hesiod.so.2" "ILP32" "1.3.1"))))

(defrule missing-libnss_nis-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_nis.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_nis.so.2" "ILP32" "1.3.1"))))

(defrule missing-libnss_nisplus-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_nisplus.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_nisplus.so.2" "ILP32" "1.3.1"))))

(defrule missing-libpanel-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpanel.so.5)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpanel.so.5" "ILP32" "1.3.1"))))

(defrule missing-libpanelw-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpanelw.so.5)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpanelw.so.5" "ILP32" "1.3.1"))))

(defrule missing-libpthread-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpthread.so.0)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpthread.so.0" "ILP32" "1.3.1"))))

(defrule missing-libresolv-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libresolv.so.2)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libresolv.so.2" "ILP32" "1.3.1"))))

(defrule missing-librt-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname librt.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "librt.so.1" "ILP32" "1.3.1"))))

(defrule missing-libstdc++5-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libstdc++.so.5)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libstdc++.so.5" "ILP32" "1.3.1"))))

(defrule missing-libthread_db-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libthread_db.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libthread_db.so.1" "ILP32" "1.3.1"))))

(defrule missing-libutil-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libutil.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libutil.so.1" "ILP32" "1.3.1"))))

(defrule missing-libuuid-x86
  "Library requirement removed for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.3.1))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libuuid.so.1)
               (libarch x86)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libuuid.so.1" "ILP32" "1.3.1"))))

(defrule missing-libBrokenLocale-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libBrokenLocale.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libBrokenLocale.so.1" "LP64" ?iv))))

(defrule missing-libSegFault-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libSegFault.so)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libSegFault.so" "LP64" ?iv))))

(defrule missing-libanl-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libanl.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libanl.so.1" "LP64" ?iv))))

(defrule missing-libc-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libc.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libc.so.6" "LP64" ?iv))))

(defrule missing-libcidn-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcidn.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcidn.so.1" "LP64" ?iv))))

(defrule missing-libcrypt-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcrypt.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcrypt.so.1" "LP64" ?iv))))

(defrule missing-libcrypto-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libcrypto.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libcrypto.so.6" "LP64" ?iv))))

(defrule missing-libdl-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libdl.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libdl.so.2" "LP64" ?iv))))

(defrule missing-libgcc_s-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libgcc_s.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libgcc_s.so.1" "LP64" ?iv))))

(defrule missing-libjpeg-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libjpeg.so.62)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libjpeg.so.62" "LP64" ?iv))))

(defrule missing-libm-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libm.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libm.so.6" "LP64" ?iv))))

(defrule missing-libnsl-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnsl.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnsl.so.1" "LP64" ?iv))))

(defrule missing-libnss_compat-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_compat.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_compat.so.2" "LP64" ?iv))))

(defrule missing-libnss_dns-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_dns.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_dns.so.2" "LP64" ?iv))))

(defrule missing-libnss_files-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_files.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_files.so.2" "LP64" ?iv))))

(defrule missing-libnss_hesiod-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_hesiod.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_hesiod.so.2" "LP64" ?iv))))

(defrule missing-libnss_ldap-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_ldap.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_ldap.so.2" "LP64" ?iv))))

(defrule missing-libnss_nis-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_nis.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_nis.so.2" "LP64" ?iv))))

(defrule missing-libnss_nisplus-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libnss_nisplus.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libnss_nisplus.so.2" "LP64" ?iv))))

(defrule missing-libpanel-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpanel.so.5)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpanel.so.5" "LP64" ?iv))))

(defrule missing-libpanelw-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpanelw.so.5)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpanelw.so.5" "LP64" ?iv))))

(defrule missing-libpthread-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libpthread.so.0)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libpthread.so.0" "LP64" ?iv))))

(defrule missing-libresolv-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libresolv.so.2)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libresolv.so.2" "LP64" ?iv))))

(defrule missing-librt-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname librt.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "librt.so.1" "LP64" ?iv))))

(defrule missing-libstdc++5-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libstdc++.so.5)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libstdc++.so.5" "LP64" ?iv))))

(defrule missing-libstdc++6-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libstdc++.so.6)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libstdc++.so.6" "LP64" ?iv))))

(defrule missing-libthread_db-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libthread_db.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libthread_db.so.1" "LP64" ?iv))))

(defrule missing-libutil-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libutil.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libutil.so.1" "LP64" ?iv))))

(defrule missing-libuuid-x86-64
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libuuid.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libuuid.so.1" "LP64" ?iv))))

(defrule missing-libxcb-x86-64
"Library requirement added for ICR 1.4 and higher"
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (icr-version 1.4))
  ?obj <- (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a SIGN) (id "libraries-data-missing") (node_id ?node)))
  (not (object (is-a LIBRARIES) (node_id ?node) (libname libxcb.so.1)
               (libarch x86-64)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90)
                 (severity 80) (state observed) (source ?obj) (value TRUE)
                 (id "missing-icr-library")
                 (args (create$ "libxcb.so.1" "LP64" "1.4"))))

(defrule icr-libraries-data-is-too-old
  "Identify nodes where the most recent LIBRARIES data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a LIBRARIES specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? libraries $?) (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  ?obj <- (object (is-a LIBRARIES) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "icr-libraries-data-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "icr-libraries-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))


