; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule memory-data-missing
  "Check that memory data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? memory $?))
  (object (is-a NODE) (node_id ?node))
  (not (object (is-a MEMORY) (node_id ?node)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "memory-data-missing")
                 (remedy "memory-data-missing-remedy")))

(defrule memory-minimum-per-core
  "Check that the amount of physical memory per core is >= 0.5 GiB.
   Requirement removed for ICR 1.4 and later."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? memory $?) (icr-version 1.3.1))
  ?obj <- (object (is-a MEMORY) (node_id ?node) (physical-per-core ?mem&~0))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (test (< ?mem 536870912))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 80)
                 (state observed) (source ?obj) (value TRUE)
                 (id "memory-minimum-per-core")
                 (args ?mem)
                 (remedy "memory-minimum-per-core-remedy")))

(defrule memory-minimum-per-core-missing
  "Check that the amount of physical memory per core is available.
   Requirement removed for ICR 1.4 and later."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? memory $?) (icr-version 1.3.1))
  ?obj <- (object (is-a MEMORY) (node_id ?node) (physical-per-core ?mem&0))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 80)
                 (state observed) (source ?obj) (value TRUE)
                 (id "memory-minimum-per-core-missing")
                 (remedy "memory-minimum-per-core-missing-remedy")))

(defrule memory-minimum-required
  "Check that the amount of physical memory is >= 8 GiB."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? memory $?))
  ?obj <- (object (is-a MEMORY) (node_id ?node) (physical-total ?mem))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (test (< ?mem 8589934592))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 80)
                 (state observed) (source ?obj) (value TRUE)
                 (id "memory-minimum-required")
                 (args ?mem)
                 (remedy "memory-minimum-required-remedy")))

(defrule memory-not-uniform
  "Check that the amount of physical memory is uniform."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? memory $?) (memory-uniformity-threshold ?threshold))
  ?obj <- (object (is-a MEMORY) (node_id ?node) (physical-total ?mem)
                  (statistics_control TRUE))
  (test (> (abs (- (send ?obj median (send ?obj statistics-key physical-total))
                   ?mem)) ?threshold))
  =>
  (bind ?median (send ?obj median (send ?obj statistics-key physical-total)))
  (bind ?severity (* (/ (abs (- ?median ?mem)) ?median) 80))
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 75) (severity ?severity)
                 (state observed) (source ?obj) (value TRUE)
                 (id "memory-not-uniform")
                 (args (create$ ?mem ?median ?threshold))))

(defrule memory-data-is-too-old
  "Identify nodes where the most recent MEMORY data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a MEMORY specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config])
          (clck-mode certification | compliance | health)
          (clck-checks $? memory $?) (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  ?obj <- (object (is-a MEMORY) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "memory-data-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "memory-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))
