; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule miccheck-data-missing
  "Check that miccheck data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? miccheck $?))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (object (is-a XEON_PHI_PCI_DEVICE) (node_id ?node))
  (not (object (is-a MICCHECK_HOST) (node_id ?node)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "miccheck-data-missing")
                 (remedy "miccheck-data-missing-remedy")))

; Use this rule to set a failure flag
(defrule miccheck-host-num-dev-os-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?obj <- (object (is-a MICCHECK_HOST) (node_id ?node) (latest-timestamp TRUE)
                  (chk_num_dev_os FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-host-num-dev-os-failure")))

(defrule miccheck-host-driver-loaded-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?obj <- (object (is-a MICCHECK_HOST) (node_id ?node) (latest-timestamp TRUE)
                  (chk_driver_loaded FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-host-driver-load-failure")))

(defrule miccheck-host-num-dev-driver-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?obj <- (object (is-a MICCHECK_HOST) (node_id ?node) (latest-timestamp TRUE)
                  (chk_num_dev_driver FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 50) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-host-num-dev-driver-failure")))

(defrule miccheck-host-mpssd-run-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?obj <- (object (is-a MICCHECK_HOST) (node_id ?node) (latest-timestamp TRUE)
                  (chk_mpssd_run FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-host-mpssd-run-failure")))

(defrule miccheck-device-online-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?host <- (object (is-a MICCHECK_HOST) (node_id ?node)
                   (latest-timestamp TRUE))
  ?obj <- (object (is-a MICCHECK_DEVICE) (host ?host) (device_id ?dev)
                  (chk_dev_online FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-device-online-failure")
                 (args ?dev)))

(defrule miccheck-device-daemon-available-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?host <- (object (is-a MICCHECK_HOST) (node_id ?node)
                   (latest-timestamp TRUE))
  ?obj <- (object (is-a MICCHECK_DEVICE) (host ?host) (device_id ?dev)
                  (chk_daemon_available FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-device-daemon-available-failure")
                 (args ?dev)))

(defrule miccheck-device-flash-version-failure
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?))
  ?host <- (object (is-a MICCHECK_HOST) (node_id ?node)
                   (latest-timestamp TRUE))
  ?obj <- (object (is-a MICCHECK_DEVICE) (host ?host) (device_id ?dev)
                  (chk_flash_version FAIL))
  (object (is-a NODE) (node_id ?node))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 33) (source ?obj)
                 (state observed) (value TRUE)
                 (id "miccheck-device-flash-version-failure")
                 (args ?dev)))

(defrule miccheck-data-is-too-old
  "Identify nodes where the most recent MICCHECK data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a MICCHECK specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? miccheck $?) (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node))
  ?obj <- (object (is-a MICCHECK_HOST) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "miccheck-data-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "miccheck-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))
