; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule mpi_internode-data-missing
  "Check that MPI inter node data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? mpi_internode $?))
  (object (is-a NODE) (node_id ?node)
          (role $?role&:(member$ compute ?role)|:(member$ enhanced ?role)))
  (not (object (is-a MPI_INTERNODE) (node_id ?node)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "mpi_internode-data-missing")
                 (remedy "mpi_internode-data-missing-remedy")))

(defrule mpi-internode-broken
  "Check whether MPI intra node 'Hello World' is functional."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
          (clck-checks $? mpi_internode $?))
  (object (is-a NODE) (node_id ?node)
          (role $?role&:(member$ compute ?role)|:(member$ enhanced ?role)))
  ?obj <- (object (is-a MPI_INTERNODE) (node_id ?node) (status FAIL))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (source ?obj) (value TRUE)
                 (id "mpi-internode-broken")
                 (args (send ?obj get-impi-setting-string))))

(defrule mpi-internode-data-is-too-old
  "Identify nodes where the most recent MPI_INTERNODE data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a MPI_INTERNODE specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config]) (clck-checks $? mpi_internode $?)
          (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node)
          (role $?role&:(member$ compute ?role)|:(member$ enhanced ?role)))
  ?obj <- (object (is-a MPI_INTERNODE) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "mpi-internode-data-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "mpi-internode-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))
