; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule offload_phi-data-missing
  "Check that Intel(R) Xeon Phi(TM) coprocessor offload data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? offload_phi $?))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (object (is-a  XEON_PHI_PCI_DEVICE) (node_id ?node))
  (not (object (is-a OFFLOAD_PHI) (node_id ?node)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "offload_phi-data-missing")
                 (remedy "offload_phi-data-missing-remedy")))

(defrule offload-failure
  "If Intel(R) Xeon Phi(TM) coprocessors are installed on the system,
   but one or more of the Phi cards fails offload. This will fire
   warning that one or more cards failed to offload correctly"
  (object (is-a CONFIG) (name [config]) (clck-mode compliance | health)
          (clck-checks $? offload_phi $?))
  ?obj <- (object (is-a OFFLOAD_PHI) (node_id ?hostname)
                  (num_offload_phi ?offload)
                  (num_lspci_phi ?lspci) (stderr ?err))
  (object (is-a NODE) (node_id ?hostname))
  (test (and (> ?lspci ?offload) (> ?lspci 0)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?hostname)
                 (confidence 90) (severity 90) (source ?obj)
                 (state observed) (value TRUE) (id "offload-failure")
                 (args (create$ (- ?lspci ?offload) ?lspci))))

(defrule offload-phi-data-is-too-old
  "Identify nodes where the most recent OFFLOAD_PHI data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a OFFLOAD_PHI specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config])
          (clck-mode certification | compliance | health)
          (clck-checks $? offload_phi $?) (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node))
  ?obj <- (object (is-a OFFLOAD_PHI) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "offload-phi-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "offload-phi-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))
