; Copyright 2006-2016 Intel Corporation All Rights Reserved.
;
; The source code contained or described herein and all documents
; related to the source code ("Material") are owned by Intel
; Corporation or its suppliers or licensors. Title to the Material
; remains with Intel Corporation or its suppliers and licensors. The
; Material may contain trade secrets and proprietary and confidential
; information of Intel Corporation and its suppliers and licensors,
; and is protected by worldwide copyright and trade secret laws and
; treaty provisions. No part of the Material may be used, copied,
; reproduced, modified, published, uploaded, posted, transmitted,
; distributed, or disclosed in any way without Intel's prior express
; written permission.
;
; No license under any patent, copyright, trade secret or other
; intellectual property right is granted to or conferred upon you by
; disclosure or delivery of the Materials, either expressly, by
; implication, inducement, estoppel or otherwise. Any license under
; such intellectual property rights must be express and approved by
; Intel in writing.
;
; Unless otherwise agreed by Intel in writing, you may not remove or
; alter this notice or any other notice embedded in Materials by Intel
; or Intel's suppliers or licensors in any way.

(defrule storage-data-missing
  "Check that storage data is available."
  (object (is-a CONFIG) (name [config]) (clck-checks $? storage $?))
  (object (is-a NODE) (node_id ?node) (architecture x86_64))
  (not (object (is-a STORAGE) (node_id ?node)))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node)
                 (confidence 90) (severity 90)
                 (state observed) (value TRUE)
                 (id "storage-data-missing")
                 (remedy "storage-data-missing-remedy")))

(defrule storage-icr-compute
  "Checks the Intel(R) Cluster Ready required minimum for compute node storage.
   The head node must be attached to 20GiB of storage local or
   remote."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? storage $?) (icr-version ?iv&1.4|1.3.1))
  ?obj <- (object (is-a STORAGE) (node_id ?node)
                  (blocks_local ?blocks_local)
                  (blocks_network ?blocks_network))
  (object (is-a NODE) (node_id ?node) (architecture x86_64) (role $?role))
  (test (member$ compute ?role))
  (test (not (or (member$ head ?role) (member$ storage ?role))))
  (test (< (+ ?blocks_local ?blocks_network) 21474836480))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 50) (severity 80)
                 (state observed) (source ?obj) (value TRUE)
                 (id "storage-icr-compute")
                 (args (create$ (+ ?blocks_local ?blocks_network)
                                21474836480 ?iv))))

(defrule storage-icr-head
  "Checks the Intel(R) Cluster Ready required minimum for head node storage.
   The head node must be attached to 200GiB of direct access storage."
  (object (is-a CONFIG) (name [config]) (clck-mode certification | compliance)
          (clck-checks $? storage $?) (icr-version ?iv&1.3.1|1.4))
  ?obj <- (object (is-a STORAGE) (node_id ?node)
                  (blocks_local ?blocks_local))
  (object (is-a NODE) (node_id ?node) (architecture x86_64) (role $?role))
  (test (or (member$ head ?role) (member$ storage ?role)))
  (test (< ?blocks_local 214748364800))
  =>
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 50) (severity 80)
                 (state observed) (source ?obj) (value TRUE)
                 (id "storage-icr-head")
                 (args (create$ ?blocks_local 214748364800 ?iv))))

(defrule storage-data-is-too-old
  "Identify nodes where the most recent STORAGE data should be
   considered too old.  Do not fire if there is not a recent
   heartbeat, i.e., the node is not returning any data and there is a
   not a STORAGE specific issue.  Too old is defined to mean no data
   from the last 7 days (604800 seconds)."
  (object (is-a CONFIG) (name [config]) (clck-checks $? storage $?)
          (data-age-threshold ?age-threshold))
  (object (is-a NODE) (node_id ?node))
  ?obj <- (object (is-a STORAGE) (node_id ?node) (timestamp ?t))
  (not (object (is-a SIGN) (node_id ?node) (id "storage-data-is-too-old")))
  (not (object (is-a SIGN) (node_id ?node) (id "heartbeat-is-too-old")))
  (test (< ?t (- (now) ?age-threshold)))
  =>
  (bind ?age (round (- (now) ?t)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 90) (severity 20)
                 (state observed) (value TRUE) (source ?obj)
                 (id "storage-data-is-too-old")
                 (args (create$ ?age ?age-threshold))))

(defrule storage-free-space
   (object (is-a CONFIG) (name [config]) (clck-mode certification | health)
           (clck-checks $? storage $?) (storage-max-used-pct ?storage-max-used-pct))
   ?obj <- (object (is-a STORAGE_MOUNT_POINT)
                  (node_id ?node)
                  (mount_point ?mount_point)
                  (blocks_used ?blocks_used)
                  (blocks_total ?blocks_total))
  (object (is-a NODE) (node_id ?node) (architecture x86_64) (role $?role))
  (test (>= (* 100 (/ ?blocks_used ?blocks_total)) ?storage-max-used-pct))
  =>
  (bind ?x (* 100 (/ ?blocks_used ?blocks_total)))
  (bind ?sigma (/ (- 100 ?storage-max-used-pct) 3))
  (bind ?severity (* 90 (gaussian ?x 100 ?sigma)))
  (make-instance of BOOLEAN_SIGN (node_id ?node) (confidence 80) (severity ?severity)
                  (state observed) (source ?obj) (value TRUE)
                  (id "storage-free-space")
                  (args (create$ ?mount_point ?x (- ?blocks_total ?blocks_used)))))


